@@ -38,13 +38,13 @@ struct lttng_evaluation_session_rotation_comm {
 } LTTNG_PACKED;
 
 LTTNG_HIDDEN
-ssize_t lttng_condition_session_rotation_ongoing_create_from_buffer(
-		const struct lttng_buffer_view *view,
+ssize_t lttng_condition_session_rotation_ongoing_create_from_payload(
+		struct lttng_payload_view *view,
 		struct lttng_condition **condition);
 
 LTTNG_HIDDEN
-ssize_t lttng_condition_session_rotation_completed_create_from_buffer(
-		const struct lttng_buffer_view *view,
+ssize_t lttng_condition_session_rotation_completed_create_from_payload(
+		struct lttng_payload_view *view,
 		struct lttng_condition **condition);
 
 LTTNG_HIDDEN
@@ -58,13 +58,13 @@ struct lttng_evaluation *lttng_evaluation_session_rotation_completed_create(
 		struct lttng_trace_archive_location *location);
 
 LTTNG_HIDDEN
-ssize_t lttng_evaluation_session_rotation_ongoing_create_from_buffer(
-		const struct lttng_buffer_view *view,
+ssize_t lttng_evaluation_session_rotation_ongoing_create_from_payload(
+		struct lttng_payload_view *view,
 		struct lttng_evaluation **evaluation);
 
 LTTNG_HIDDEN
-ssize_t lttng_evaluation_session_rotation_completed_create_from_buffer(
-		const struct lttng_buffer_view *view,
+ssize_t lttng_evaluation_session_rotation_completed_create_from_payload(
+		struct lttng_payload_view *view,
 		struct lttng_evaluation **evaluation);
 
 #endif /* LTTNG_CONDITION_SESSION_ROTATION_INTERNAL_H */
