@@ -9,8 +9,16 @@
 
 static
 struct lttng_endpoint lttng_session_daemon_notification_endpoint_instance = {
-	.type = LTTNG_ENDPOINT_TYPE_DEFAULT_SESSIOND_NOTIFICATION
+	.type = LTTNG_ENDPOINT_TYPE_DEFAULT_SESSIOND_NOTIFICATION,
+};
+
+static
+struct lttng_endpoint lttng_session_daemon_command_endpoint_instance = {
+	.type = LTTNG_ENDPOINT_TYPE_DEFAULT_SESSIOND_COMMAND,
 };
 
 struct lttng_endpoint *lttng_session_daemon_notification_endpoint =
 		&lttng_session_daemon_notification_endpoint_instance;
+
+struct lttng_endpoint *lttng_session_daemon_command_endpoint =
+		&lttng_session_daemon_command_endpoint_instance;
